@@ -13,22 +13,23 @@ function( object , file = NULL , ...){
    if ( class(object) == "tam.latreg" ){
 		latreg <- TRUE 
 		object$irtmodel <- "tam.latreg"
-						}
+	}
 
 	cat("------------------------------------------------------------\n")
-    d1 <- utils::packageDescription("TAM")
-	cat( paste( d1$Package , " " , d1$Version , " (" , d1$Date , ")" , 
-			sep="") , "\n\n" )	
-	cat( "Date of Analysis:" , paste( object$time[2] ) , "\n" )
-	cat("Computation time:" , print(object$time[2] - object$time[1]), "\n")
-	cat( Rsessinfo() , "\n\n")			
+	
+	cat( tam_packageinfo("TAM") , "\n" )	
+	cat( tam_rsessinfo() , "\n\n")				
+	
+	cat( "Date of Analysis:" , paste(object$time[2]) , "\n" )
+	cat("Computation time:" , print(object$time[2] - object$time[1]), "\n\n")
+	
     cat("Multidimensional Item Response Model in TAM \n\n")
 	irtmodel <- object$irtmodel
 	
-	cat("IRT Model" , irtmodel ) # , "\n")
+	cat("IRT Model" , irtmodel )
 	
 	# print Call
-    print_CALL(object$CALL)	
+    tam_print_call(object$CALL)	
 	
 	cat("------------------------------------------------------------\n")
 	cat( "Number of iterations =" , object$iter , "\n" )
